@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *             zhaolong <zhaolong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "mainwindow.h"
 #include "mainpanelcontrol.h"
@@ -161,6 +143,7 @@ void MainWindow::launch()
         bool showDock = true;
         if (m_dconfig.data()->isValid())
             showDock = !m_dconfig.data()->value("alwaysHideDock", false).toBool();
+        qApp->setProperty("ALWAYS_HIDE_DOCK", !showDock);
         setVisible(showDock);
         if (!showDock && m_multiScreenWorker->dockInter()) {
             m_multiScreenWorker->dockInter()->setHideMode(KeepHidden);
@@ -316,6 +299,7 @@ void MainWindow::initComponents()
         connect(m_dconfig.data(), &DConfig::valueChanged, this, [this] (const QString &key) {
             if (key == "alwaysHideDock") {
                 const bool showDock = !m_dconfig.data()->value(key, false).toBool();
+                qApp->setProperty("ALWAYS_HIDE_DOCK", !showDock);
                 setVisible(showDock);
                 if (!showDock && m_multiScreenWorker->dockInter()) {
                     m_multiScreenWorker->dockInter()->setHideMode(KeepHidden);
@@ -696,3 +680,13 @@ void MainWindow::sendNotifications()
                 .call();
     });
 }
+
+void MainWindow::setVisible(bool visible)
+{
+    // 设置了始终隐藏的情况下，任务栏将永远不显示
+    if (visible && qApp->property("ALWAYS_HIDE_DOCK").toBool()) {
+        return;
+    }
+
+    return DBlurEffectWidget::setVisible(visible);
+}
