@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     chenwei <chenwei@uniontech.com>
- *
- * Maintainer: chenwei <chenwei@uniontech.com>
- *
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "bluetoothadapteritem.h"
 #include "adapter.h"
@@ -44,7 +26,7 @@ BluetoothDeviceItem::BluetoothDeviceItem(QStyle *style, const Device *device, DL
     , m_labelAction(nullptr)
     , m_stateAction(nullptr)
     , m_connAction(nullptr)
-    , m_loading(new DSpinner(parent))
+    , m_loading(new DSpinner(parent->viewport()))
     , m_iconWidget(new QWidget(parent->viewport()))
     , m_connButton(new StateButton(m_iconWidget))
 {
@@ -124,20 +106,25 @@ void BluetoothDeviceItem::updateIconTheme(DGuiApplicationHelper::ColorType type)
 void BluetoothDeviceItem::updateDeviceState(Device::State state)
 {
     m_labelAction->setText(m_device->alias());
+
+    m_connAction->setVisible(state == Device::StateConnected);
+    m_stateAction->setVisible(state == Device::StateAvailable);
+
     if (state == Device::StateAvailable) {
         m_loading->start();
-        m_stateAction->setVisible(true);
-        m_connAction->setVisible(false);
     } else if (state == Device::StateConnected) {
         m_loading->stop();
-        m_stateAction->setVisible(false);
-        m_connAction->setVisible(true);
         emit requestTopDeviceItem(m_standarditem);
+
+        /* 已连接的Item插入到首位后，其设置的 DViewItemAction 对象的位置未更新，导致还是显示在原位置
+        手动设置其位置到首位，触发 DViewItemAction 对象的位置更新，规避该问题，该问题待后期DTK优化 */
+        QRect loadingRect = m_loading->geometry();
+        loadingRect.setY(0);
+        m_loading->setGeometry(loadingRect);
     } else {
         m_loading->stop();
-        m_stateAction->setVisible(false);
-        m_connAction->setVisible(false);
     }
+
     emit deviceStateChanged(m_device);
 }
 
@@ -187,10 +174,11 @@ void BluetoothAdapterItem::onTopDeviceItem(DStandardItem *item)
     if (!item || item->row() == -1 || item->row() == 0)
         return;
 
-    int index1 = item->row();
-    QStandardItem *index = m_deviceModel->takeItem(index1, 0);
-    m_deviceModel->removeRow(index1);
-    m_deviceModel->insertRow(0, index);
+    int row = item->row();
+    // 先获取，再移除，后插入
+    QStandardItem *sItem = m_deviceModel->takeItem(row, 0);
+    m_deviceModel->removeRow(row);
+    m_deviceModel->insertRow(0, sItem);
 }
 
 void BluetoothAdapterItem::onAdapterNameChanged(const QString name)
@@ -200,10 +188,17 @@ void BluetoothAdapterItem::onAdapterNameChanged(const QString name)
 
 void BluetoothAdapterItem::updateIconTheme(DGuiApplicationHelper::ColorType type)
 {
-    if (type == DGuiApplicationHelper::LightType)
+    QPalette widgetBackgroud;
+    if (type == DGuiApplicationHelper::LightType) {
         m_refreshBtn->setRotateIcon(":/wireless/resources/wireless/refresh_dark.svg");
-    else
+        widgetBackgroud.setColor(QPalette::Background, QColor(255, 255, 255, 0.03 * 255));
+    } else {
+        widgetBackgroud.setColor(QPalette::Background, QColor(0, 0, 0, 0.03 * 255));
         m_refreshBtn->setRotateIcon(":/wireless/resources/wireless/refresh.svg");
+    }
+
+    m_adapterLabel->label()->setAutoFillBackground(true);
+    m_adapterLabel->label()->setPalette(widgetBackgroud);
 }
 
 QSize BluetoothAdapterItem::sizeHint() const
@@ -234,7 +229,8 @@ QStringList BluetoothAdapterItem::connectedDevicesName()
 void BluetoothAdapterItem::initData()
 {
     m_showUnnamedDevices = m_bluetoothInter->displaySwitch();
-    if (!m_adapter->powered())
+
+    if (m_adapter && !m_adapter->powered())
         return;
 
     foreach (const auto device, m_adapter->devices()) {
@@ -264,10 +260,10 @@ void BluetoothAdapterItem::onDeviceAdded(const Device *device)
         }
     });
 
-    m_deviceItems.insert(device->id(), item);
-    if (!m_showUnnamedDevices && device->name().isEmpty() && Device::StateConnected != device->state())
+    if (!m_showUnnamedDevices && device->name().isEmpty())
         return;
 
+    m_deviceItems.insert(device->id(), item);
     m_deviceModel->insertRow(insertRow, item->standardItem());
     emit deviceCountChanged();
 }
@@ -277,7 +273,18 @@ void BluetoothAdapterItem::onDeviceRemoved(const Device *device)
     if (m_deviceItems.isEmpty())
         return;
 
-    m_deviceModel->removeRow(m_deviceItems.value(device->id())->standardItem()->row());
+    int row = -1;
+    if (!m_deviceItems.value(device->id()))
+        return;
+
+    row = m_deviceItems.value(device->id())->standardItem()->row();
+    if ((row < 0) || (row > m_deviceItems.size() - 1)) {
+        m_deviceItems.value(device->id())->deleteLater();
+        m_deviceItems.remove(device->id());
+        return;
+    }
+
+    m_deviceModel->removeRow(row);
     m_deviceItems.value(device->id())->deleteLater();
     m_deviceItems.remove(device->id());
     emit deviceCountChanged();
@@ -424,7 +431,6 @@ void BluetoothAdapterItem::setUnnamedDevicesVisible(bool isShow)
         return;
     }
 
-
     for (i = m_deviceItems.begin(); i != m_deviceItems.end(); ++i) {
         BluetoothDeviceItem *deviceItem = i.value();
 
