@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "sounditem.h"
 #include "constants.h"
@@ -205,9 +188,9 @@ void SoundItem::refreshIcon()
             volumeString = "muted";
         else if (int(volmue) == 0)
             volumeString = "off";
-        else if (volmue / maxVolmue > double(2) / 3)
+        else if (volmue / maxVolmue > 0.6)
             volumeString = "high";
-        else if (volmue / maxVolmue > double(1) / 3)
+        else if (volmue / maxVolmue > 0.3)
             volumeString = "medium";
         else
             volumeString = "low";
